use strict;
use warnings;
use Test::More;
use YAML::XS;

my $yaml = <<'EOM';
- test
EOM

eval {
    my $xs = YAML::XS->new;
    my $data = $xs->load($yaml);
};
is $@, '', "no eval error";

done_testing;
